aboutsummaryrefslogtreecommitdiff
path: root/views/default/output/confirmlink.php
diff options
context:
space:
mode:
Diffstat (limited to 'views/default/output/confirmlink.php')
-rw-r--r--views/default/output/confirmlink.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/views/default/output/confirmlink.php b/views/default/output/confirmlink.php
index 31a34ae63..953c15f1b 100644
--- a/views/default/output/confirmlink.php
+++ b/views/default/output/confirmlink.php
@@ -6,16 +6,16 @@
* @package Elgg
* @subpackage Core
*
* @uses $vars['text'] The text of the link
* @uses $vars['href'] The address
* @uses $vars['title'] The title text (defaults to confirm text)
* @uses $vars['confirm'] The dialog text
* @uses $vars['text_encode'] Encode special characters? (false)
*/
$vars['rel'] = elgg_extract('confirm', $vars, elgg_echo('question:areyousure'));
$vars['rel'] = addslashes($vars['rel']);
-$encode = elgg_extract('text_encode', $vars, false);
+$encode = elgg_extract('encode_text', $vars, false);
// always generate missing action tokens
$vars['href'] = elgg_add_action_tokens_to_url(elgg_normalize_url($vars['href']), true);
@@ -6,16 +6,16 @@
* @subpackage Core
*
- * @uses $vars['text'] The text of the link
- * @uses $vars['href'] The address
- * @uses $vars['title'] The title text (defaults to confirm text)
- * @uses $vars['confirm'] The dialog text
- * @uses $vars['text_encode'] Encode special characters? (false)
+ * @uses $vars['text'] The text of the link
+ * @uses $vars['href'] The address
+ * @uses $vars['title'] The title text (defaults to confirm text)
+ * @uses $vars['confirm'] The dialog text
+ * @uses $vars['encode_text'] Run $vars['text'] through htmlspecialchars() (false)
*/
$vars['rel'] = elgg_extract('confirm', $vars, elgg_echo('question:areyousure'));